==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/lang/english.php <==
<?
define("_TOP5_DESC","Top 5 stories most viewed");
define("_HOT5_DESC","Top 5 stories with most comments");
define("_LASTC5_DESC","Last 5 comments stories");
define("_STORY_EXT","Extended Story Configuration");
define("_STORY_LINK_INDEX","Index Names (story links)");
define("_STORY_LINK_INDEX_ADD","Add a new Index Name");
define("_STORY_LINK_INDEX_KILL","Killing index names will kill all associated story links as well");

define("_LINK_ANYONE","Anyone can add (moderated)");
define("_LINK_ONLYADMIN","Only admin can add");
define("_LINK_FREE","Anyone can add");
# logs.php
define("_LOGS_NOTHING","Nothing recorded");
define("_LOGS_RESET","Reset");

# layout.php
define("_LAYOUT_EDITOR","Layout Editor: ");
define("_LAYOUT_VIEW","View/Load");
define("_LAYOUT_KILL","Kill");
define("_LAYOUT_ADD","Add/Update");
define("_LAYOUT_AUTHOR","Author");
define("_LAYOUT_DESC","Description");
define("_LAYOUT_BG","BG Image");
define("_LAYOUT_LOGO","Logo Image");
define("_LAYOUT_FONT","Font Family");
define("_LAYOUT_WIDTH","Page Width");

define("_LAYOUT_TITLE_COLOR","Story Title Text");
define("_LAYOUT_BLOCK_WIDTH","Block Width");
define("_LAYOUT_BLOCK_ALIGN","Default Blocks Align");
define("_LAYOUT_THEME","Themes / Templates");
define("_LAYOUT_B_LEFT","Left Block");
define("_LAYOUT_B_RIGHT","Right Block");
define("_LAYOUT_ADDED","Layout file added as");
define("_NOTKILL","You cannot kill the active layout. Nothing changed.");

# for Log Messages
define("_UPDATE_STORY","Updated story");
define("_REPOST_STORY","Reposted story");
define("_UPDATE_BLOCK","Updated Block");
define("_UPDATE_REPLY","Updated Comments");
define("_UPDATE_TOPIC","Updated Topic");
define("_ADD_TOPIC","Added new topic");
define("_ADD_POLL","Created Poll");
define("_ADD_BLOCK","Added block");
define("_UPDATE_POLL","Updated poll");
define("_UPDATE_CATE","Updated Link Category");
define("_LOG_RESET","Log Reset");
define("_UPDATE_LAYOUT","Updated layout");
define("_DELETE_LAYOUT","Deleted layout");
define("_UPDATE_SITE","Updated site configuration.");
define("_UPDATE_STORY_CONF","Updated story configuration.");
define("_UPDATE_REPLY_CONF","Updated reply configuration.");
define("_UPDATE_EXT_CONF","Updated extended configuration.");
define("_DELETE_ITEM","Deleted item");
define("_UNABLE_DEL","Unable to delete");
define("_DEL_POLL","Deleted Poll");
define("_DEL_TOPIC","Deleted Topic");
define("_DEL_CATE","Deleted link category");

# for Additional Control Page
define("_SHOW_PTIME","Show processing time");
define("_SHOW_NUM","Show number of story");
define("_CATCH_REPLY","All replys will send to admin");
define("_FORM_WRAP","Text area WRAP");
define("_QP_ENCODE","Quoted-Printable encoding when sending mail");
define("_USE_THEME","User-selectable themes");
define("_THEMES","Which themes user can choose");
define("_ANTI_SPAM","Anti Spam function");
define("_ANTI_SPAM2","Post blocking IP");
define("_ANTI_IP","IP blocking");
define("_BLOCK_IP_LIST","Access deny IP list");
define("_SPAM_LIST","Spam reserved word (regex)");
define("_BLOCK_LIST","Post blocking IP list");
define("_SHOW_CONTACT","Show Contact link in navigation bar");
define("_CONT_ADD_TXT","Additional text for contrib page");
define("_LOGIN_AD_TXT","Additional text for login box");
define("_TOTAL_COUNT_IN_TOPIC","Show total num of stories,replys in topic block");
define("_REPLY_HTML_PARSE_LEVEL","HTML Parse Level for comment");
define("_REPLY_PAGES","Use page system for comment display");
define("_FILE_CACHE","Use file caching for RDF,RSS,URL,INCLUDE");
define("_SHOW_IP","Show writer's ip address in story and comment");
define("_ENABLE_BUTTON","Enable next/prev story link");
define("_ENABLE_DAY","Display day of week in older stories block");
define("_REREPLY","send email to reply's writer");
define("_FEATURE_TITLE","Title of Feature block");
define("_UC_SCORE","Login user scoring(when reply)");
define("_RSS_POPWINDOW","Add \"target=_blank\" tag for rss block");

# topics.php
define("_TOPIC_IMAGE","Image");
define("_TOPIC_TITLE","Title");
define("_TOPIC_ALTTAG","ALT Tag");
define("_TOPIC_RULE","Rule");
define("_TOPIC_KILL","All stories/comments will be delete.");
define("_TOPIC_ADD","New Topic");
define("_TOPIC_IMG_NULL","Null: not using");
define("_TOPIC_NO_POST","Not allowed post");
define("_TOPIC_NO_COMMENT","Not allowed comment");

# http referer
define("_REFER_LIMIT","recored limit");
define("_REFER_LIMIT_NO","infinity");
define("_SHOW_ALL","show all");

# browser, os recored
define("_COUNTER","record browser/os (stats)");
define("_TIME_COUNTER","access counter by time");
define("_COUNT_INIT","initialize");

# menu block
define("_MENU_BLOCK","main menu block");

# session
define("_SESSION","Use session (check who's online)");
define("_SESSION_TMOUT","<font size=\"-1\">Users become inactive after not using the system for: ");
define("_SESSION_MIN","minutes</font>");
define("_ONLY_SESSION","(work only when <a href=\"user-ext.php\">Session init</a> is on)");

# private msg
define("_PRIVATE_MSG","user private message");
define("_PRIV_MSG_LIMIT","message limit");

# user
define("_LEVEL","level");
define("_NORMAL_USER","User");
define("_MODERATOR","Moderator");
define("_SCORE_MODERATOR","Score Moderator");
define("_TOTAL","Total");
define("_USER_ADMIN","User Admin");
define("_USER_ADD","Add");
define("_USER_FIND","Find");
define("_USER_EDIT","Edit");
define("_USER_KILL","Kill");
define("_SENDMAIL","send inform mail to user");
define("_UPDATED_USERDB","updated user info");
define("_USER_ADDED","new user added.");
define("_USER_DELETED","user deleted.");

# submit log
define("_UPDATED","updated");

define("_MORECONFIG","more");

# user-ext
define("_ONLINE_USER_INFO_DISPLAY","Display online user infomation");
define("_STORY_WATCH","Story Watching");
define("_REGIST_METHOD","Check email address when registration");
define("_USER_IMG","User image link");
define("_COOKIE_TIME","login users cookie expire time");
define("_DAY","days");

define("_STORY_WATING","programmed story");
define("_NO_PROGRAM_STORY","No programmed story");
define("_AUTO_STORY","Story Program");
define("_STORY_PROGRAM","Story programming");
define("_PROGRAM_SAVED","Story Stored.");
define("_CURRENT_TIME","Current time");
define("_YEAR","year");
define("_UMONTH","month");
define("_HOUR","hour");
define("_MINUTE","minute");
define("_POSTING_TIME","posting time");
define("_STORY_PROGRAM_EDITED","change saved.");
define("_STORY_PROGRAM_DELETED","programmed story deleted");

define("_BMARK_LIMIT","limit number of bookmark");

# admin_msg.php
define("_ADMIN_MSG","Admin Message");
define("_ADMIN_MSG_EDIT","Edit");
define("_ADMIN_MSG_ADD","Add");
define("_DISPLAY","Active");
define("_ACTIVE","On");
define("_INACTIVE","Off");
define("_DISPLAY_TYPE","Type");
define("_EXPIRE","Expire");
define("_CONTENT","Content");

define("_COPYRIGHT","Copyright");
define("_NOLOGIN_USER","Not using login user feature");

# sql.php
define("_PHP_INFO","Show PHP information");
define("_SQL_RUNTIME","Runtime information");
define("_SQL_SYSTEM_VAR","System variables");
define("_SQL_PROCESS","Running Processes");
define("_SQL_CHECK_TABLE","Check Tables");
define("_SQL_REPAIR_TABLE","Repair Tables");
define("_SQL_OPTIMIZE_TABLE","Optimize Tables");
define("_SQL_BACKUP_TABLE","BackUp Tables");
define("_SQL_DOCUMENT","Documentation");
define("_SQL_ADMIN","SQL admin");

# navigator.php
define("_NAVIGATOR","Navigator");
define("_NAVIG_TOP","Top Navigation Bar");
define("_NAVIG_BLOCK","Navigation Block");
define("_NAVIG_MOVE","Move");
define("_NAVIG_NAME","Link");
define("_NAVIG_ORDER","Sort");
define("_NAVIG_ADD","Add link");
define("_NAVIG_EDIT","Edit link");
define("_NAVIG_DISPLAY_NAME","Name");
define("_NAVIG_URL","Url");

# faq.php
define("_NEW_FAQ","Make New FAQ");
define("_FAQ_TITLE","FAQ Title");
define("_ADD_QA","Add Question & Answer");
define("_EDIT_QA","Edit Question & Answer");
define("_EDIT_FAQ","Edit FAQ Title");

# htmltag.php
define("_HTML_OPTION","HTML TAG Option");
define("_HTML_OPTION1","You have to choose more then one tags");

# config-story.php
define("_HTML_PARSE_LEVEL","Default HTML Parse Level");
define("_RDF_USE","Export RDF/RSS Stories");
define("_MAILING_USE","Story Mailing List");
define("_USER_PARSE","Allow select parsing level");
define("_EXPORT_RDF_NOW","RSS file export now");
define("_EXPORT_RDF_NOW1","RSS file exported.");
define("_THUMBNAIL","Create Thumbnail");
define("_IMAGICK","Imagick Program (Complete Path) Enter the Path to the convert program of imagick, normally /usr/bin/convert");
define("_MAX_PIC_PIXEL","Maximum Image Dimensions Here you can define the maximum allowed Image Dimension to be attached (Width x Height in pixels).");
define("_THUMB_SIZE","Thumb size (Width in pixel)");
define("_NO_IMAGICK","Can not find convert binary!");

# polls.php
define("_POLL_QUES","Question");
define("_POLL_ADD","Add a New Poll");
define("_POLL_DISP","Display");
define("_POLL_EXPIRE","cookie expiration (days)");
define("_POLL_ANSWER","Answer");

# random_link.php
define("_RANDOM_LINK_ADD","Add link");
define("_RANDOM_LINK_EDIT","Edit link");
define("_RANDOM_LINK_TITLE","Name");
define("_RANDOM_LINK_NUMS","Number of links to display");
define("_RANDOM_LINK_HEAD","Random link block title");
define("_RANDOM_LINK_SOURCE","Random link source");
define("_RLINK_PREF1","here...");
define("_RLINK_PREF2","from link db");
define("_RLINK_PREF3","from story related link");

# random_button.php
define("_RANDOM_BUTTON_ADD","Button add");
define("_RANDOM_BUTTON_EDIT","Button edit");
define("_RANDOM_BUTTON_ALT","Alt text");
define("_RANDOM_BUTTON_NUMS","Number of buttons to display");
define("_RANDOM_BUTTON_HEAD","Random button block title");


# banners.php
define("_BANNER","Banner");
define("_BANNER_LOCATION","Banner display location");
define("_BANNER_LOCATION_DESC","You have to add \"\$banner\" variable in site theme file \"header.tmpl\" or \"footer.tmpl\"");
define("_BANNER_ALT","ALT text");
define("_BANNER_ADD","Banner Add");
define("_BANNER_EDIT","Banner Edit");

# blocks.php
define("_BLOCK_STORY_ONLY","Display block on the main page only");
define("_BLOCK_RDF_SUPP","Supports RSS/RDF format.");
define("_BLOCK_INCLUDE","full URL or path only");
define("_BLOCK_CACHE","Cache Time");
define("_BLOCK_CACHE_DESC","minutes / 0=no cache");
define("_NOT_URL","Unable to find URL or path");
define("_MAX_ITEMS","Maximum number of links shown");

# config-site.php
define("_UNIQUEKEY","Security Key");
define("_KEYDESC","You must change once before installation");

# config-new.php
define("_STORY_LST","This article's comments limited anonymous user reading (Story Rid).");

# user-mail.php
define("_ALL","all");
define("_MAIL_SEND","send");
define("_GROUP_MAIL","send mail to user group");
define("_GROUP","user group");
define("_SENDMAIL_WARN","Maybe send mail process take long time. Please click \"send\" button once, and wait for the next screen to appear. Clicking on \"send\" button multiple times or exit browser can cause the send mail process to fail.");

# lost files (attachment.php)
define("_LOST_FILES","Lost Files");
define("_LOST_FILES_DESC","Here you can delete attachment data from postings when the files are missing from your filesystem, and delete files that are no longer attached to any postings. You can download or view a file if you click on it; if no link is present, the file does not exist.");
define("_LOST_FILES1","Missing files");
define("_LOST_FILES2","Files are not assigned to an existing story.");
define("_LOST_FILES_DEL","Delete");

# trackback msg
define("_TBMSG_LENGTH","tracked messages length");
define("_TBMSG_SHOW","showing tracked messages with comments.");
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/admin/lang/english.php <==
<?
define("_TOP5_DESC","Top 5 stories most viewed");
define("_HOT5_DESC","Top 5 stories with most comments");
define("_LASTC5_DESC","Last 5 comments stories");
define("_STORY_EXT","Extended Story Configuration");
define("_STORY_LINK_INDEX","Index Names (story links)");
define("_STORY_LINK_INDEX_ADD","Add a new Index Name");
define("_STORY_LINK_INDEX_KILL","Killing index names will kill all associated story links as well");

define("_LINK_ANYONE","Anyone can add (moderated)");
define("_LINK_ONLYADMIN","Only admin can add");
define("_LINK_FREE","Anyone can add");
# logs.php
define("_LOGS_NOTHING","Nothing recorded");
define("_LOGS_RESET","Reset");

# layout.php
define("_LAYOUT_EDITOR","Layout Editor: ");
define("_LAYOUT_VIEW","View/Load");
define("_LAYOUT_KILL","Kill");
define("_LAYOUT_ADD","Add/Update");
define("_LAYOUT_AUTHOR","Author");
define("_LAYOUT_DESC","Description");
define("_LAYOUT_BG","BG Image");
define("_LAYOUT_LOGO","Logo Image");
define("_LAYOUT_FONT","Font Family");
define("_LAYOUT_WIDTH","Page Width");

define("_LAYOUT_TITLE_COLOR","Story Title Text");
define("_LAYOUT_BLOCK_WIDTH","Block Width");
define("_LAYOUT_BLOCK_ALIGN","Default Blocks Align");
define("_LAYOUT_THEME","Themes / Templates");
define("_LAYOUT_B_LEFT","Left Block");
define("_LAYOUT_B_RIGHT","Right Block");
define("_LAYOUT_ADDED","Layout file added as");
define("_NOTKILL","You cannot kill the active layout. Nothing changed.");

# for Log Messages
define("_UPDATE_STORY","Updated story");
define("_REPOST_STORY","Reposted story");
define("_UPDATE_BLOCK","Updated Block");
define("_UPDATE_REPLY","Updated Comments");
define("_UPDATE_TOPIC","Updated Topic");
define("_ADD_TOPIC","Added new topic");
define("_ADD_POLL","Created Poll");
define("_ADD_BLOCK","Added block");
define("_UPDATE_POLL","Updated poll");
define("_UPDATE_CATE","Updated Link Category");
define("_LOG_RESET","Log Reset");
define("_UPDATE_LAYOUT","Updated layout");
define("_DELETE_LAYOUT","Deleted layout");
define("_UPDATE_SITE","Updated site configuration.");
define("_UPDATE_STORY_CONF","Updated story configuration.");
define("_UPDATE_REPLY_CONF","Updated reply configuration.");
define("_UPDATE_EXT_CONF","Updated extended configuration.");
define("_DELETE_ITEM","Deleted item");
define("_UNABLE_DEL","Unable to delete");
define("_DEL_POLL","Deleted Poll");
define("_DEL_TOPIC","Deleted Topic");
define("_DEL_CATE","Deleted link category");

# for Additional Control Page
define("_SHOW_PTIME","Show processing time");
define("_SHOW_NUM","Show number of story");
define("_CATCH_REPLY","All replys will send to admin");
define("_FORM_WRAP","Text area WRAP");
define("_QP_ENCODE","Quoted-Printable encoding when sending mail");
define("_USE_THEME","User-selectable themes");
define("_THEMES","Which themes user can choose");
define("_ANTI_SPAM","Anti Spam function");
define("_ANTI_SPAM2","Post blocking IP");
define("_ANTI_IP","IP blocking");
define("_BLOCK_IP_LIST","Access deny IP list");
define("_SPAM_LIST","Spam reserved word (regex)");
define("_BLOCK_LIST","Post blocking IP list");
define("_SHOW_CONTACT","Show Contact link in navigation bar");
define("_CONT_ADD_TXT","Additional text for contrib page");
define("_LOGIN_AD_TXT","Additional text for login box");
define("_TOTAL_COUNT_IN_TOPIC","Show total num of stories,replys in topic block");
define("_REPLY_HTML_PARSE_LEVEL","HTML Parse Level for comment");
define("_REPLY_PAGES","Use page system for comment display");
define("_FILE_CACHE","Use file caching for RDF,RSS,URL,INCLUDE");
define("_SHOW_IP","Show writer's ip address in story and comment");
define("_ENABLE_BUTTON","Enable next/prev story link");
define("_ENABLE_DAY","Display day of week in older stories block");
define("_REREPLY","send email to reply's writer");
define("_FEATURE_TITLE","Title of Feature block");
define("_UC_SCORE","Login user scoring(when reply)");
define("_RSS_POPWINDOW","Add \"target=new\" tag for RSS block");
define("_RSS_BUTTON","Display RSS Button");

# topics.php
define("_TOPIC_IMAGE","Image");
define("_TOPIC_TITLE","Title");
define("_TOPIC_ALTTAG","ALT Tag");
define("_TOPIC_RULE","Rule");
define("_TOPIC_KILL","All stories/comments will be delete.");
define("_TOPIC_ADD","New Topic");
define("_TOPIC_IMG_NULL","Null: not using");
define("_TOPIC_NO_POST","Not allowed post");
define("_TOPIC_NO_COMMENT","Not allowed comment");

# http referer
define("_REFER_LIMIT","recored limit");
define("_REFER_LIMIT_NO","infinity");
define("_SHOW_ALL","show all");

# browser, os recored
define("_COUNTER","record browser/os (stats)");
define("_TIME_COUNTER","access counter by time");
define("_COUNT_INIT","initialize");

# menu block
define("_MENU_BLOCK","main menu block");

# session
define("_SESSION","Use session (check who's online)");
define("_SESSION_TMOUT","<font size=\"-1\">Users become inactive after not using the system for: ");
define("_SESSION_MIN","minutes</font>");
define("_ONLY_SESSION","(work only when <a href=\"user-ext.php\">Session init</a> is on)");

# private msg
define("_PRIVATE_MSG","user private message");
define("_PRIV_MSG_LIMIT","message limit");

# user
define("_LEVEL","level");
define("_NORMAL_USER","User");
define("_MODERATOR","Moderator");
define("_SCORE_MODERATOR","Score Moderator");
define("_TOTAL","Total");
define("_USER_ADMIN","User Admin");
define("_USER_ADD","Add");
define("_USER_FIND","Find");
define("_USER_EDIT","Edit");
define("_USER_KILL","Kill");
define("_SENDMAIL","send inform mail to user");
define("_UPDATED_USERDB","updated user info");
define("_USER_ADDED","new user added.");
define("_USER_DELETED","user deleted.");

# submit log
define("_UPDATED","updated");

define("_MORECONFIG","more");

# user-ext
define("_ONLINE_USER_INFO_DISPLAY","Display online user infomation");
define("_STORY_WATCH","Story Watching");
define("_REGIST_METHOD","Check email address when registration");
define("_USER_IMG","User image link");
define("_COOKIE_TIME","login users cookie expire time");
define("_DAY","days");

define("_STORY_WATING","programmed story");
define("_NO_PROGRAM_STORY","No programmed story");
define("_AUTO_STORY","Story Program");
define("_STORY_PROGRAM","Story programming");
define("_PROGRAM_SAVED","Story Stored.");
define("_CURRENT_TIME","Current time");
define("_YEAR","year");
define("_UMONTH","month");
define("_HOUR","hour");
define("_MINUTE","minute");
define("_POSTING_TIME","posting time");
define("_STORY_PROGRAM_EDITED","change saved.");
define("_STORY_PROGRAM_DELETED","programmed story deleted");

define("_BMARK_LIMIT","limit number of bookmark");

# admin_msg.php
define("_ADMIN_MSG","Admin Message");
define("_ADMIN_MSG_EDIT","Edit");
define("_ADMIN_MSG_ADD","Add");
define("_DISPLAY","Active");
define("_ACTIVE","On");
define("_INACTIVE","Off");
define("_DISPLAY_TYPE","Type");
define("_EXPIRE","Expire");
define("_CONTENT","Content");

define("_COPYRIGHT","Copyright");
define("_NOLOGIN_USER","Not using login user feature");

# sql.php
define("_PHP_INFO","Show PHP information");
define("_SQL_RUNTIME","Runtime information");
define("_SQL_SYSTEM_VAR","System variables");
define("_SQL_PROCESS","Running Processes");
define("_SQL_CHECK_TABLE","Check Tables");
define("_SQL_REPAIR_TABLE","Repair Tables");
define("_SQL_OPTIMIZE_TABLE","Optimize Tables");
define("_SQL_BACKUP_TABLE","BackUp Tables");
define("_SQL_DOCUMENT","Documentation");
define("_SQL_ADMIN","SQL admin");

# navigator.php
define("_NAVIGATOR","Navigator");
define("_NAVIG_TOP","Top Navigation Bar");
define("_NAVIG_BLOCK","Navigation Block");
define("_NAVIG_MOVE","Move");
define("_NAVIG_NAME","Link");
define("_NAVIG_ORDER","Sort");
define("_NAVIG_ADD","Add link");
define("_NAVIG_EDIT","Edit link");
define("_NAVIG_DISPLAY_NAME","Name");
define("_NAVIG_URL","Url");

# faq.php
define("_NEW_FAQ","Make New FAQ");
define("_FAQ_TITLE","FAQ Title");
define("_ADD_QA","Add Question & Answer");
define("_EDIT_QA","Edit Question & Answer");
define("_EDIT_FAQ","Edit FAQ Title");

# htmltag.php
define("_HTML_OPTION","HTML TAG Option");
define("_HTML_OPTION1","You have to choose more then one tags");

# config-story.php
define("_USERONLY_POST","Registered User post only");
define("_HTML_PARSE_LEVEL","Default HTML Parse Level");
define("_RDF_USE","Export RDF/RSS Stories");
define("_MAILING_USE","Story Mailing List");
define("_USER_PARSE","Allow select parsing level");
define("_EXPORT_RDF_NOW","RSS Cache file export now");
define("_EXPORT_RDF_NOW1","RSS file exported.");
define("_THUMBNAIL","Create Thumbnail");
define("_IMAGICK","Imagick Program (Complete Path) Enter the Path to the convert program of imagick, normally /usr/bin/convert");
define("_MAX_PIC_PIXEL","Maximum Image Dimensions Here you can define the maximum allowed Image Dimension to be attached (Width x Height in pixels).");
define("_THUMB_SIZE","Thumb size (Width in pixel)");
define("_NO_IMAGICK","Can not find convert binary!");

# polls.php
define("_POLL_QUES","Question");
define("_POLL_ADD","Add a New Poll");
define("_POLL_DISP","Display");
define("_POLL_EXPIRE","cookie expiration (days)");
define("_POLL_ANSWER","Answer");

# random_link.php
define("_RANDOM_LINK_ADD","Add link");
define("_RANDOM_LINK_EDIT","Edit link");
define("_RANDOM_LINK_TITLE","Name");
define("_RANDOM_LINK_NUMS","Number of links to display");
define("_RANDOM_LINK_HEAD","Random link block title");
define("_RANDOM_LINK_SOURCE","Random link source");
define("_RLINK_PREF1","here...");
define("_RLINK_PREF2","from link db");
define("_RLINK_PREF3","from story related link");

# random_button.php
define("_RANDOM_BUTTON_ADD","Button add");
define("_RANDOM_BUTTON_EDIT","Button edit");
define("_RANDOM_BUTTON_ALT","Alt text");
define("_RANDOM_BUTTON_NUMS","Number of buttons to display");
define("_RANDOM_BUTTON_HEAD","Random button block title");


# banners.php
define("_BANNER","Banner");
define("_BANNER_LOCATION","Banner display location");
define("_BANNER_LOCATION_DESC","You have to add \"\$banner\" variable in site theme file \"header.tmpl\" or \"footer.tmpl\"");
define("_BANNER_ALT","ALT text");
define("_BANNER_ADD","Banner Add");
define("_BANNER_EDIT","Banner Edit");

# blocks.php
define("_BLOCK_STORY_ONLY","Display block on the main page only");
define("_BLOCK_RDF_SUPP","Supports RSS/RDF format.");
define("_BLOCK_INCLUDE","full URL or path only");
define("_BLOCK_CACHE","Cache Time");
define("_BLOCK_CACHE_DESC","minutes / 0=no cache");
define("_NOT_URL","Unable to find URL or path");
define("_MAX_ITEMS","Maximum number of links shown");

# config-site.php
define("_UNIQUEKEY","Security Key");
define("_KEYDESC","You must change once before installation");

# config-new.php
define("_STORY_LST","This article's comments limited anonymous user reading (Story Rid).");

# user-mail.php
define("_ALL","all");
define("_MAIL_SEND","send");
define("_GROUP_MAIL","send mail to user group");
define("_GROUP","user group");
define("_SENDMAIL_WARN","Maybe send mail process take long time. Please click \"send\" button once, and wait for the next screen to appear. Clicking on \"send\" button multiple times or exit browser can cause the send mail process to fail.");

# lost files (attachment.php)
define("_LOST_FILES","Lost Files");
define("_LOST_FILES_DESC","Here you can delete attachment data from postings when the files are missing from your filesystem, and delete files that are no longer attached to any postings. You can download or view a file if you click on it; if no link is present, the file does not exist.");
define("_LOST_FILES1","Missing files");
define("_LOST_FILES2","Files are not assigned to an existing story.");
define("_LOST_FILES_DEL","Delete");

# trackback msg
define("_TBMSG_LENGTH","tracked messages length");
define("_TBMSG_SHOW","showing tracked messages with comments.");
define("_EXCERPT_PARSE_LEVEL","tracked messages parse level");
?>
